@@ -7,16 +7,19 @@ class Credentials:
   __token: Optional[str] = None
   __token_expiration: str = ""
   __endpoint: Optional[str] = None
+  __clientName: Optional[str] = None
 
   def __init__(
       self,
       email: str,
       password: str,
-      endpoint: str = "https://tim-platform-test.tangent.works/api/v5",
+      endpoint: str = "https://tim-platform.tangent.works/api/v5",
+      clientName: str = "Python Client",
   ):
     self.__email = email
     self.__password = password
     self.__endpoint = endpoint
+    self.__clientName = clientName
 
   @property
   def email(self):
@@ -34,6 +37,10 @@ class Credentials:
   def endpoint(self):
     return self.__endpoint
 
+  @property
+  def clientName(self):
+    return self.__clientName
+
   @property
   def token_expiration(self):
     return self.__token_expiration
