@@ -3,9 +3,9 @@ from .anomaly_detection import (
     build_model as build_anomaly_detection_model, detect, get_anomaly_detection_logs,
     execute_anomaly_detection, get_anomaly_detection_job_status, get_anomaly_detection,
     get_anomaly_detection_table_results, get_anomaly_detection_model_results, poll_anomaly_detection_status,
-    get_anomaly_detection_jobs
+    get_anomaly_detection_jobs, delete_anomaly_detection
 )
 from .types import (
     AnomalyDetectionJobConfiguration, AnomalyDetection, AnomalyDetectionJobModelResult,
-    ExecuteAnomalyDetectionJobResponse, AnomalyDetectionResultsResponse
+    AnomalyDetectionResultsResponse
 )
