@@ -1,10 +1,10 @@
 from io import StringIO
 import pandas as pd
-from typing import List, Union
+from typing import Callable, List, Optional, Union
 from time import sleep
 from tim.types import ExecuteResponse, Logs, Status, StatusResponse
 from tim.core.api import execute_request
-from tim.data_sources.anomaly_detection.types import AnomalyDetectionJobModelResult, AnomalyDetection, BuildModelResponse, AnomalyDetectionJobConfiguration, AnomalyDetectionDetectConfiguration, AnomalyDetectionListPayload
+from tim.data_sources.anomaly_detection.types import AnomalyDetectionJobModelResult, AnomalyDetection, BuildModelResponse, AnomalyDetectionJobConfiguration, AnomalyDetectionDetectConfiguration
 from tim.core.credentials import Credentials
 
 
@@ -46,16 +46,29 @@ def get_anomaly_detection(credentials: Credentials, id: str) -> AnomalyDetection
 
 def get_anomaly_detection_jobs(
     credentials: Credentials,
-    offset: int,
-    limit: int,
-    sort: str,
+    offset: Union[int, None] = None,
+    limit: Union[int, None] = None,
+    sort: Union[str, None] = None,
     experiment_id: Union[str, None] = None,
     use_case_id: Union[str, None] = None,
     type: Union[str, None] = None,
+    status: Union[str, None] = None,
+    parent_id: Union[str, None] = None,
+    from_datetime: Union[str, None] = None,
+    to_datetime: Union[str, None] = None
 ) -> List[AnomalyDetection]:
-  payload = AnomalyDetectionListPayload(
-      experimentId=experiment_id, useCaseId=use_case_id, sort=sort, type=type, limit=limit, offset=offset
-  )
+  payload = {
+      "experimentId": experiment_id,
+      "useCaseId": use_case_id,
+      "sort": sort,
+      "type": type,
+      "status": status,
+      "parentId": parent_id,
+      "from": from_datetime,
+      "to": to_datetime,
+      "limit": limit,
+      "offset": offset
+  }
 
   return execute_request(credentials=credentials, method='get', path=f'/detection-jobs', params=payload)
 
@@ -74,17 +87,28 @@ def get_anomaly_detection_model_results(credentials: Credentials, id: str) -> An
   return execute_request(credentials=credentials, method='get', path=f'/detection-jobs/{id}/results/model')
 
 
-def poll_anomaly_detection_status(credentials: Credentials, id: str, tries_left: int = 20) -> StatusResponse:
+def poll_anomaly_detection_status(
+    credentials: Credentials,
+    id: str,
+    handle_status_poll: Optional[Callable[[StatusResponse], None]] = None,
+    tries_left: int = 150
+) -> StatusResponse:
   if tries_left < 1:
     raise ValueError("Timeout error.")
 
   response = get_anomaly_detection_job_status(credentials, id)
+  if handle_status_poll: handle_status_poll(response)
+
   if Status(response['status']).value == Status.FAILED.value:
     return response
   if Status(response['status']).value != Status.FINISHED.value and Status(
       response['status']
   ).value != Status.FINISHED_WITH_WARNING.value:
     sleep(2)
-    return poll_anomaly_detection_status(credentials, id, tries_left - 1)
+    return poll_anomaly_detection_status(credentials, id, handle_status_poll, tries_left - 1)
 
   return response
+
+
+def delete_anomaly_detection(credentials: Credentials, id: str) -> ExecuteResponse:
+  return execute_request(credentials=credentials, method="delete", path=f"/detection-jobs/{id}")
