@@ -1,10 +1,10 @@
 from time import sleep
 from pandas.core.frame import DataFrame
-from typing import List, Union
+from typing import List, Union, Callable, Optional
 from tim.core.credentials import Credentials
 from tim.core.api import execute_request
-from tim.types import Logs, Status, StatusResponse
-from .types import CSVSeparator, DatasetListPayload, Dataset, DatasetListVersion, UploadCsvResponse, UploadCSVConfiguration
+from tim.types import Logs, Status, ExecuteResponse
+from .types import CSVSeparator, DatasetStatusResponse, DatasetListPayload, Dataset, DatasetListVersion, UploadCsvResponse, UploadCSVConfiguration
 
 
 def __is_valid_csv_configuration(configuration: UploadCSVConfiguration) -> bool:
@@ -36,26 +36,32 @@ def upload_csv(
   )
 
 
-def get_version_status(credentials: Credentials, id: str, versionId: str) -> StatusResponse:
+def get_version_status(credentials: Credentials, id: str, version_id: str) -> DatasetStatusResponse:
   return execute_request(
       credentials=credentials,
       method="get",
-      path=f"/datasets/{id}/versions/{versionId}/status",
+      path=f"/datasets/{id}/versions/{version_id}/status",
   )
 
 
 def poll_dataset_version_status(
-    credentials: Credentials, id: str, versionId: str, tries_left: int = 5
-) -> StatusResponse:
+    credentials: Credentials,
+    id: str,
+    version_id: str,
+    handle_status_poll: Optional[Callable[[DatasetStatusResponse], None]] = None,
+    tries_left: int = 150
+) -> DatasetStatusResponse:
   if tries_left < 1:
     raise ValueError("Timeout error.")
 
-  response = get_version_status(credentials, id, versionId)
+  response = get_version_status(credentials, id, version_id)
+  if handle_status_poll: handle_status_poll(response)
+
   if response['status'] == Status.FAILED.value:  # pyright: reportUnnecessaryComparison=false
     return response
   if response['status'] != Status.FINISHED.value and response['status'] != Status.FINISHED_WITH_WARNING.value:
     sleep(2)
-    return poll_dataset_version_status(credentials, id, versionId, tries_left - 1)
+    return poll_dataset_version_status(credentials, id, version_id, handle_status_poll, tries_left - 1)
 
   return response
 
@@ -64,6 +70,10 @@ def get_dataset(credentials: Credentials, id: str) -> Dataset:
   return execute_request(credentials=credentials, method="get", path=f"/datasets/{id}")
 
 
+def delete_dataset(credentials: Credentials, id: str) -> ExecuteResponse:
+  return execute_request(credentials=credentials, method="delete", path=f"/datasets/{id}")
+
+
 def get_dataset_logs(credentials: Credentials, id: str) -> List[Logs]:
   return execute_request(
       credentials=credentials,
