@@ -1,7 +1,7 @@
 # pyright: reportUnusedImport=false
 from .forecast import (
     build_model as build_forecasting_model, execute, get_status, get_forecast_logs,
-    get_forecast_accuracies_result, get_forecast, get_forecast_model_results, get_forecast_table_results,
-    poll_forecast_status
+    get_forecast_accuracies_result, get_forecast, get_forecasting_jobs, get_forecast_model_results,
+    get_forecast_table_results, poll_forecast_status, delete_forecast
 )
 from .types import BuildForecastingModelConfiguration, ForecastJobConfiguration
